
# Slot: node_list_numeric_node_type_ids


Whether to load the node types IDs in the node file to be numeric.

URI: [https://w3id.org/neat/ensmallenRunConfig__node_list_numeric_node_type_ids](https://w3id.org/neat/ensmallenRunConfig__node_list_numeric_node_type_ids)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
